@@ -2,6 +2,6 @@ from .files import bnp_open, count_entries
 from .indexed_files import open_indexed
 from .multiline_buffer import MultiLineFastaBuffer
 from .file_buffers import (TwoLineFastaBuffer, FastQBuffer)
-from .delimited_buffers import (BedBuffer, VCFBuffer, PhasedVCFMatrixBuffer, VCFMatrixBuffer,
+from .delimited_buffers import (BedBuffer, Bed6Buffer, VCFBuffer, PhasedVCFMatrixBuffer, VCFMatrixBuffer,
                                 GfaSequenceBuffer, get_bufferclass_for_datatype)
 from .indexed_fasta import IndexedFasta
